/******************************************************************************/
/*                                                                            */
/*              SAS Program for TIMSS 2011 User Guide  Example 5              */
/*        TIMSS 2011 International Results in Mathematics Exhibit 7.6         */
/*                                                                            */
/******************************************************************************/

* Specify the path for the SAS data files following the format x:\xxx\ ;
* <datpath> must be edited ;

LIBNAME T11 "<datpath>" ;

* Issue the include command to include the JACKGPV macro in the program ;
* <macpath> must be edited following the format x:\xxx\ ;

%INCLUDE "<macpath>JACKPV.SAS" ;

* Get and sort the teacher data ;

PROC SORT DATA = T11.BTMALLM5 OUT = BTMALLM5 ;
     BY IDCNTRY IDTEACH IDLINK ;
RUN ;

* Get and sort the student-teacher linkage data ;

PROC SORT DATA = T11.BSTALLM5 OUT = BSTALLM5 ;
     BY IDCNTRY IDTEACH IDLINK ;
RUN ;

* Merge the two files ;

DATA MERGED ;
     MERGE BTMALLM5 (IN = INBTM)
           BSTALLM5 (IN = INBST) ;
     BY IDCNTRY IDTEACH IDLINK ;
     IF INBTM AND INBST ;
RUN ;

* Read the merged file and select cases of interest ;

DATA MERGED ;
     SET MERGED ;

     * Select cases with no missing data ;

     IF NMISS (BTDG01) = 0 ;

RUN ;

* Define formats for the variables used ;

PROC FORMAT LIBRARY = WORK ;

 VALUE COUNTRY
   051 = "ARMENIA"
   036 = "AUSTRALIA"
   048 = "BAHRAIN"
   152 = "CHILE"
   158 = "CHINESE TAIPEI"
   926 = "ENGLAND"
   246 = "FINLAND"
   268 = "GEORGIA"
   288 = "GHANA"
   344 = "HONG KONG SAR"
   348 = "HUNGARY"
   360 = "INDONESIA"
   364 = "IRAN, ISLAMIC REP. OF"
   376 = "ISRAEL"
   380 = "ITALY"
   392 = "JAPAN"
   400 = "JORDAN"
   398 = "KAZAKHSTAN"
   410 = "KOREA, REP. OF"
   422 = "LEBANON"
   440 = "LITHUANIA"
   807 = "MACEDONIA, REP. OF"
   458 = "MALAYSIA"
   504 = "MOROCCO"
   554 = "NEW ZEALAND"
   578 = "NORWAY"
   512 = "OMAN"
   275 = "PALESTINIAN NAT'L AUTH."
   634 = "QATAR"
   642 = "ROMANIA"
   643 = "RUSSIAN FEDERATION"
   682 = "SAUDI ARABIA"
   702 = "SINGAPORE"
   705 = "SLOVENIA"
   752 = "SWEDEN"
   760 = "SYRIAN ARAB REPUBLIC"
   764 = "THAILAND"
   788 = "TUNISIA"
   792 = "TURKEY"
   804 = "UKRAINE"
   784 = "UNITED ARAB EMIRATES"
   840 = "UNITED STATES"
   072 = "BOTSWANA"
   340 = "HONDURAS"
   710 = "SOUTH AFRICA"
  9134 = "ALBERTA, CANADA"
  9132 = "ONTARIO, CANADA"
  9133 = "QUEBEC, CANADA"
  7842 = "ABU DHABI, UAE"
  7841 = "DUBAI, UAE"
 10400 = "ALABAMA, US"
 10800 = "COLORADO, US"
 10900 = "CONNECTICUT, US"
 11100 = "CALIFORNIA, US"
 11200 = "FLORIDA, US"
 11800 = "INDIANA, US"
 12500 = "MASSACHUSETTS, US"
 12700 = "MINNESOTA, US"
 13700 = "NORTH CAROLINA, US" ;

 VALUE BTDG
     1 = "20 YEARS OR MORE"
     2 = "AT LEAST 10 BUT LESS THAN 20 YEARS"
     3 = "AT LEAST 5 BUT LESS THAN 10 YEARS"
     4 = "LESS THAN 5 YEARS" ;

RUN ;

* Invoke the JACKPV macro to compute the statistics ;

%JACKPV (MATWGT, JKZONE, JKREP, 75, IDCNTRY BTDG01, BSMMAT0, 5, MERGED) ;

* Print the results ;

PROC PRINT DATA = FINAL NOOBS ;
     VAR IDCNTRY BTDG01 N MATWGT MNPV MNPV_SE PCT PCT_SE ;
     FORMAT IDCNTRY COUNTRY. BTDG01 BTDG. N 6.0 MATWGT 10.0
            MNPV MNPV_SE PCT PCT_SE 6.2 ;
RUN ;
