/******************************************************************************/
/*                                                                            */
/*       SAS Program to Join SAS Data Files into a Single SAS Data File       */
/*                           TIMSS 2011  User Guide                           */
/*                                                                            */
/******************************************************************************/

OPTIONS NONOTES ;

* Specify the file type ;
* <type> must be edited ;

%LET TYPE = <type> ;

* Specify the path for the SAS data files following the format x:\xxx\ ;
* <path> must be edited ;

LIBNAME LIBDAT "<path>" ;

%MACRO DOIT ;

   * Specify the list of countries to be processed ;

   %IF %UPCASE(%SUBSTR(&TYPE,1,1)) = A %THEN %DO; * 4th grade countries ;

      %LET COUNTRY = ARM AUS AUT AZE BHR BFL CHL TWN HRV CZE
                     DNK ENG FIN GEO DEU HKG HUN IRN IRL ITA
                     JPN KAZ KOR KWT LTU MLT MAR NLD NZL NIR
                     NOR OMN POL PRT QAT ROM RUS SAU SRB SGP
                     SVK SVN ESP SWE THA TUN TUR ARE USA YEM
                     BWA HND YE6
                     CAB COT CQU AAD ADU UFL UNC ;

      %IF %UPCASE(%SUBSTR(&TYPE,3,1)) = H %THEN %DO ; * Countries for ASH ;

         %LET COUNTRY = AUS AUT AZE TWN HRV CZE FIN GEO DEU HKG
                        HUN IRN IRL ITA LTU MLT MAR NOR NIR OMN
                        POL PRT QAT ROM RUS SAU SGP SVK SVN ESP
                        SWE ARE
                        BWA HND
                        CQU AAD ADU ;

      %END ;

   %END ;

   %IF %UPCASE(%SUBSTR(&TYPE,1,1)) = B %THEN %DO ; * 8th grade countries ;

      %LET COUNTRY = ARM AUS BHR CHL TWN ENG FIN GEO GHA HKG
                     HUN IDN IRN ISR ITA JPN JOR KAZ KOR LBN
                     LTU MYS MKD MAR NZL NOR OMN PSE QAT ROM
                     RUS SAU SGP SVN SWE SYR THA TUN TUR UKR
                     ARE USA
                     BWA HND ZAF
                     CAB COT CQU AAD ADU UAL UCA UCO UCT UFL
                     UIN UMA UMN UNC ;

   %END;

   DATA &TYPE.ALLM5 ;
        SET %LET I = 1 ;
            %DO %WHILE(%LENGTH(%SCAN(&COUNTRY,&I))) ;
               %LET CTRY = %SCAN(&COUNTRY,&I) ;
                  LIBDAT.&TYPE&CTRY.M5
               %LET I = %EVAL(&I + 1) ;
            %END ; ;
   RUN ;

   * Specify the sorting variables ;
   * Dependent of the file type ;

   %LET SORTVARS = IDCNTRY IDSTUD ;

   %IF %UPCASE(%SUBSTR(&TYPE,2,1)) = C %THEN %DO ;
      %LET SORTVARS = IDCNTRY IDSCHOOL ; %END ;

   %IF %UPCASE(%SUBSTR(&TYPE,2,1)) = T %THEN %DO ;
      %LET SORTVARS = IDCNTRY IDTEACH IDLINK ; %END ;

   %IF %UPCASE(%SUBSTR(&TYPE,3,1)) = T %THEN %DO ;
      %LET SORTVARS = IDCNTRY IDSTUD IDTEACH IDLINK ; %END ;

   PROC SORT DATA=&TYPE.ALLM5 OUT=LIBDAT.&TYPE.ALLM5 ;
        BY &SORTVARS ;
   RUN ;

%MEND DOIT ;

%DOIT ;
