/******************************************************************************/
/*                                                                            */
/*               Sample SAS Program to Invoke the JACKREG Macro               */
/*                           TIMSS 2011  User Guide                           */
/*                                                                            */
/******************************************************************************/

* Specify the path for the SAS data files following the format x:\xxx\ ;
* <datpath> must be edited ;

LIBNAME T11 "<datpath>" ;

* Issue the include command to include the jackreg macro in the program ;
* <macpath> must be edited following the format x:\xxx\ ;

%INCLUDE "<macpath>JACKREG.SAS" ;

* Get the student data and select cases of interest ;

DATA BSGALLM5 ;
     SET T11.BSGALLM5 ;

     * Select cases with no missing data ;

     WHERE NMISS (ITSEX, BSBGSLM) = 0 ;

     * Dummy recode of ITSEX ;

     SELECT (ITSEX) ;
       WHEN (1)  REGSEX = 0 ;  * GIRLS ;
       WHEN (2)  REGSEX = 1 ;  * BOYS ;
       OTHERWISE REGSEX = . ;
     END ;

RUN ;

* Define formats for the variables used ;

PROC FORMAT LIBRARY = WORK ;

 VALUE COUNTRY
   051 = "ARMENIA"
   036 = "AUSTRALIA"
   048 = "BAHRAIN"
   152 = "CHILE"
   158 = "CHINESE TAIPEI"
   926 = "ENGLAND"
   246 = "FINLAND"
   268 = "GEORGIA"
   288 = "GHANA"
   344 = "HONG KONG SAR"
   348 = "HUNGARY"
   360 = "INDONESIA"
   364 = "IRAN, ISLAMIC REP. OF"
   376 = "ISRAEL"
   380 = "ITALY"
   392 = "JAPAN"
   400 = "JORDAN"
   398 = "KAZAKHSTAN"
   410 = "KOREA, REP. OF"
   422 = "LEBANON"
   440 = "LITHUANIA"
   807 = "MACEDONIA, REP. OF"
   458 = "MALAYSIA"
   504 = "MOROCCO"
   554 = "NEW ZEALAND"
   578 = "NORWAY"
   512 = "OMAN"
   275 = "PALESTINIAN NAT'L AUTH."
   634 = "QATAR"
   642 = "ROMANIA"
   643 = "RUSSIAN FEDERATION"
   682 = "SAUDI ARABIA"
   702 = "SINGAPORE"
   705 = "SLOVENIA"
   752 = "SWEDEN"
   760 = "SYRIAN ARAB REPUBLIC"
   764 = "THAILAND"
   788 = "TUNISIA"
   792 = "TURKEY"
   804 = "UKRAINE"
   784 = "UNITED ARAB EMIRATES"
   840 = "UNITED STATES"
   072 = "BOTSWANA"
   340 = "HONDURAS"
   710 = "SOUTH AFRICA"
  9134 = "ALBERTA, CANADA"
  9132 = "ONTARIO, CANADA"
  9133 = "QUEBEC, CANADA"
  7842 = "ABU DHABI, UAE"
  7841 = "DUBAI, UAE"
 10400 = "ALABAMA, US"
 10800 = "COLORADO, US"
 10900 = "CONNECTICUT, US"
 11100 = "CALIFORNIA, US"
 11200 = "FLORIDA, US"
 11800 = "INDIANA, US"
 12500 = "MASSACHUSETTS, US"
 12700 = "MINNESOTA, US"
 13700 = "NORTH CAROLINA, US" ;

RUN ;

* Invoke the JACKREG macro to compute the statistics ;

%JACKREG (TOTWGT, JKZONE, JKREP, 75, IDCNTRY, REGSEX, BSBGSLM, BSGALLM5) ;

* Print the results ;

PROC PRINT DATA = REG NOOBS ;
     VAR IDCNTRY N MULT_RSQ SS_TOTAL SS_REG B00 B00_SE B01 B01_SE ;
     FORMAT IDCNTRY COUNTRY. N 6.0 MULT_RSQ 5.3 SS_TOTAL SS_REG 10.0
            B00 B00_SE B01 B01_SE 6.2 ;
RUN ;
