*                                                                              .
*             SPSS Program to Score the TIMSS 2011 4th Grade Items             .
*                            TIMSS 2011  User Guide                            .
*                                                                              .

SET MPRINT=ON.

DEFINE SCOREIT (TYPE  = !CHAREND('/') /
                ITEM  = !CHAREND('/') /
                RIGHT = !CHAREND('/') /
                NR    = !CHAREND('/') /
                NA    = !CHAREND('/') /
                OM    = !CHAREND('/') /
                OTHER = !CHAREND('/') ) .

* Code for multiple-choice items .

 !IF (!UPCASE(!TYPE)=MC) !THEN
    !DO !I !IN (!ITEM) .
       RECODE !I (!RIGHT = 1      )
                 (!NR    = 0      ) /* Not Reached      */
                 (!NA    = SYSMIS ) /* Not Administered */
                 (!OM    = 0      ) /* Omitted          */
                 (!OTHER = 0      ) /* Other Missing    */
                 (ELSE   = 0      ) .
    !DOEND .
 !IFEND .

 * Code for constructed-response items .

 !IF (!UPCASE(!TYPE)=CR) !THEN
    !DO !I !IN (!ITEM).
       RECODE !I (10 THRU 19 = 1      )
                 (20 THRU 29 = 2      )
                 (70 THRU 79 = 0      )
                 (!NR        = 0      ) /* Not Reached      */
                 (!NA        = SYSMIS ) /* Not Administered */
                 (!OM        = 0      ) /* Omitted          */
                 (!OTHER     = 0      ) /* Other Missing    */
                 (ELSE       = 0      ).
    !DOEND .
 !IFEND .

!ENDDEFINE.

DEFINE DOIT (COUNTRY = !CHAREND('/') ) .

* Specify the path for the SPSS data files following the format x:\xxx\ .
* <path> must be edited .

!LET !LIBDAT = !UNQUOTE("<path>") .

* Country loop .

!DO !CTY !IN (!COUNTRY) .

* Get the student achievement data .

ADD FILES
  / FILE = !QUOTE(!CONCAT(!LIBDAT,'ASA',!CTY,'M5.SAV')) .

* Score multiple-choice items with A key .

SCOREIT  Type  = MC      /
         Item  = M051305   M041329   M041184   M051407   M031159   M041175   M041199
                 M031210   M051224   M041125   M041135   M041264   M051140   M041046
                 M041169   M051211   M051100   M041034   M051040   M051216A  S031291
                 S031068   S051049D  S051049E  S051086   S041014   S051004   S051026A
                 S051026D  S051121C  S051121E  S051105   S031410   S041178   S041305
                 S031077   S051142   S041008   S051188B  S051188C  S051188E  S051102
                 S041070   S051138B  S051191   S041010   S041017   S041124   S041303
                 S051054   /
         RIGHT = 1       /
         NR    = 6       /
         NA    = sysmis  /
         OM    = 9       /
         OTHER = 7       .

* Score multiple-choice items with B key .

SCOREIT  Type  = MC      /
         Item  = M031071   M051123   M041335   M051070   M051093   M031187   M031251
                 M041011   M031252   M031004   M051049   M051207   M041068   M041268
                 M051094   M051129   M041280   M041048   M041262   M051226   M041004
                 M041132   M051216B  M051221   S031356   S031418   S051049B  S051049C
                 S051033   S051071   S041117   S041163   S041208   S051026B  S051026C
                 S051121A  S051121B  S051121D  S051111   S031361   S031298   S041311
                 S041069   S041100   S031254   S031273   S031281   S031311   S051035
                 S041191   S051087   S051188A  S051188D  S041052   S051051   S051138A
                 S051065   S051193   S051063   /
         RIGHT = 2       /
         NR    = 6       /
         NA    = sysmis  /
         OM    = 9       /
         OTHER = 7       .

* Score multiple-choice items with C key .

SCOREIT  Type  = MC      /
         Item  = M051007   M041010   M041158   M041155   M051018   M051077   M031109
                 M041107   M041041   M031043   M031088   M051052   M051427   M041289
                 M041065A  M041151   M051017   M041333   M041177   M051075   M051103
                 M051102   M041302A  M041153   S051179   S051100   S041120   S041049
                 S051041   S051114   S031340   S031275   S041180   S051131A  S051157
                 S041223   S051185   S041050   S041209   S041102   S051029   S051099
                 S041119   S051012   S051180   S051148   /
         RIGHT = 3       /
         NR    = 6       /
         NA    = sysmis  /
         OM    = 9       /
         OTHER = 7       .

* Score multiple-choice items with D key .

SCOREIT  Type  = MC       /
         Item  = M031083   M031185   M051091   M051117   M041098   M051410   M031294
                 M031218   M041320   M041265   M031317   M031093   M031155   M051098
                 M051502   M041096   M051060   M051125B  M041298   M041007   M041271
                 M041023   M041254   M041191   M051115   S031230   S031371   S031376
                 S051032   S051156   S051110   S031236   S031001   S041187   S041092
                 S031266   S031389   S051003   S051131B  S041009   S041026   S041134C
                 S051137   S051161   S041034   S041105   S041193   S051106   /
         RIGHT = 4       /
         NR    = 6       /
         NA    = sysmis  /
         OM    = 9       /
         OTHER = 7       .

* Score Constructed-Response Items .

SCOREIT  Type  = CR      /
         Item  = M031346A  M031346B  M031346C  M031379   M031380   M031313   M051001
                 M051203   M051601   M051064A  M051064B  M051015   M051109   M041064
                 M041003   M041104   M041299   M041143   M041328   M041284   M051205
                 M051039   M051055   M051006   M051059   M051134   M031128   M031016
                 M031183   M031297   M031133   M041122   M041115A  M041115B  M041160A
                 M041160B  M041327   M041148   M031009   M031316   M031079B  M031079C
                 M031325   M051206   M051045   M051030   M051533   M051080   M041291
                 M041065B  M041257   M041182   M041200   M051111   M051089   M051227
                 M051061A  M051061B  M051061C  M051061Z  M051236   M051125A  M041059
                 M041267   M041276A  M041276B  M051401   M051402   M051131   M051217
                 M051079   M051009   M041087   M041124   M041302B  M041302C  M041165
                 M041174   M051043   M051008   M051031A  M051031B  M051508   M051507A
                 M051507B  S031325   S031197A  S031197B  S031197Z  S031044   S031390A
                 S031390B  S031390Z  S051057   S051049Z  S051173   S051074   S051119
                 S041003   S041224   S041039   S041181   S041174   S041060   S041201A
                 S041201B  S051037   S051008   S051026Z  S051130   S051121Z  S051147
                 S031391A  S031391B  S031391Z  S031421   S031076   S041182   S041013A
                 S041013B  S041067   S041048   S041110   S031233   S031204   S031299
                 S031088A  S031088B  S031088Z  S051044   S051168   S051010   S051059
                 S051151   S041177   S041183   S041195   S041134A  S041134B  S041107
                 S041113   S051048   S051164   S051186   S051007   S051188Z  S051201
                 S051095   S041027   S041043   S041006   S041301   S041033   S041077
                 S041081   S051138Z  S051194   S051077   S051200   S051075   S051175
                 S041186   S041037   S041149A  S041149B  S041149Z  S041032   S041068
                 S051024   S051132A  S051132B  S051040   S051115   /
         RIGHT =  0      /
         NR    = 96      /
         NA    = sysmis  /
         OM    = 99      /
         OTHER = 90      .

EXECUTE.

* Save the student data .

SAVE OUTFILE = !QUOTE(!CONCAT(!LIBDAT,'ASC',!CTY,'M5.SAV')) .

!DOEND .

!ENDDEFINE .

* Specify the list of countries to be processed .

DOIT COUNTRY = ARM AUS AUT AZE BHR BFL CHL TWN HRV CZE
               DNK ENG FIN GEO DEU HKG HUN IRN IRL ITA
               JPN KAZ KOR KWT LTU MLT MAR NLD NZL NIR
               NOR OMN POL PRT QAT ROM RUS SAU SRB SGP
               SVK SVN ESP SWE THA TUN TUR ARE USA YEM
               BWA HND YE6
               CAB COT CQU AAD ADU UFL UNC .
